/**
 * @module
 * Jeu de données d’exemple.
 */

import {termTypes} from '../model.js';

/**
 * Liste des termes de la base de données, contenant des maladies, des signes
 * et des symptômes.
 */
export const terms = {
    Q2840: {
        id: 'Q2840',
        name: 'Grippe',
        alias: [],
        types: [termTypes.disease],
        weight: -10.68959934320834,
        url: 'https://fr.wikipedia.org/wiki/Grippe',
    },
    Q154882: {
        id: 'Q154882',
        name: 'Légionellose',
        alias: [
            'Maladie des légionnaires',
        ],
        types: [termTypes.disease],
        weight: -11.05394782419729,
        url: 'https://fr.wikipedia.org/wiki/Légionellose',
    },
    Q155098: {
        id: 'Q155098',
        name: 'Leptospirose',
        alias: [],
        types: [termTypes.disease],
        weight: -11.3969031483456 ,
        url: 'https://fr.wikipedia.org/wiki/Leptospirose',
    },
    Q326663: {
        id: 'Q326663',
        name: 'Encéphalite à tiques',
        alias: [
            'Encéphalite d\'Europe centrale',
            'Encéphalite verno-estivale russe',
            'Méningoencéphalite à tique',
            'Méningoencéphalite diphasique',
            'Méningoencéphalite biondulante',
            'Fièvre de lait diphasique',
            'Maladie de Schneider',
            'Maladie de Kumlinge',
        ],
        types: [termTypes.disease],
        weight: -13.862833353191204,
        url: 'https://fr.wikipedia.org/wiki/Encéphalite_à_tiques',
    },
    Q133780: {
        id: 'Q133780',
        name: 'Peste',
        alias: [],
        types: [termTypes.disease],
        weight: -10.356303313736584,
        url: 'https://fr.wikipedia.org/wiki/Peste',
    },
    Q38933: {
        id: 'Q38933',
        name: 'Fièvre',
        alias: [
            'Pyrexie',
            'Hyperthermie',
            'État fébrile',
        ],
        types: [termTypes.symptom],
        weight: -10.83729224261442,
        url: 'https://wikimedi.ca/wiki/Fièvre',
    },
    Q474959: {
        id: 'Q474959',
        name: 'Myalgie',
        alias: [
            'Douleur musculaire',
        ],
        types: [termTypes.symptom],
        weight: -12.475240614075794,
        url: 'https://fr.wikipedia.org/wiki/Myalgie',
    },
    Q86: {
        id: 'Q86',
        name: 'Céphalée',
        alias: [
            'Mal de tête',
        ],
        types: [termTypes.sign],
        weight: -11.042885864744003,
        url: 'https://wikimedi.ca/wiki/C%C3%A9phal%C3%A9e',
    },
    Q1115038: {
        id: 'Q1115038',
        name: 'Rhinorrhée',
        alias: [
            'Nez qui coule',
            'Écoulement nasal',
        ],
        types: [termTypes.symptom],
        weight: -13.291547222741679,
        url: 'https://fr.wikipedia.org/wiki/Rhinorrh%C3%A9e',
    },
    Q9690: {
        id: 'Q9690',
        name: 'Fatigue',
        alias: [],
        types: [termTypes.symptom],
        weight: -12.8932707907014,
        url: 'https://wikimedi.ca/wiki/Fatigue',
    },
    Q127076: {
        id: 'Q127076',
        name: 'Vomissement',
        alias: [
            'Vomi',
            'Vomissage',
            'Vomir',
        ],
        types: [termTypes.symptom, termTypes.sign],
        weight: -11.76320423121043,
        url: 'https://fr.wikipedia.org/wiki/Vomissement',
    },
    Q178061: {
        id: 'Q178061',
        name: 'Choc circulatoire',
        alias: [
            'Insuffisance circulatoire aiguë',
        ],
        types: [termTypes.disease],
        weight: -12.48541367835562,
        url: 'https://fr.wikipedia.org/wiki/État_de_choc_circulatoire',
    },
    Q35805: {
        id: 'Q35805',
        name: 'Toux',
        alias: [
            'Tousse',
            'Toussote',
        ],
        types: [termTypes.symptom, termTypes.sign],
        weight: -12.62883965458582,
        url: 'https://wikimedi.ca/wiki/Toux',
    },
    Q647099: {
        id: 'Q647099',
        name: 'Hémoptysie',
        alias: [
            'Expectoration sanglante',
            'Crachat sanguin',
        ],
        types: [termTypes.symptom],
        weight: -11.816428715881282,
        url: 'https://wikimedi.ca/wiki/Hémoptysies',
    },
    Q653197: {
        id: 'Q653197',
        name: 'Rash',
        alias: [
            'Éruption cutanée',
        ],
        types: [termTypes.symptom, termTypes.sign],
        weight: -13.089336365426849,
        url: 'https://fr.wikipedia.org/wiki/Rash_(médecine)',
    },
    Q160796: {
        id: 'Q160796',
        name: 'Syndrome confusionnel',
        alias: [
            'Confusion mentale',
            'Délirium',
        ],
        types: [termTypes.disease],
        weight: -12.406564919730442,
        url: 'https://wikimedi.ca/wiki/Délirium',
    },
    Q186235: {
        id: 'Q186235',
        name: 'Myocardite',
        alias: [],
        types: [termTypes.disease],
        weight: -11.874480758774315,
        url: 'https://fr.wikipedia.org/wiki/Myocardite',
    },
    Q476921: {
        id: 'Q476921',
        name: 'Insuffisance rénale',
        alias: [],
        types: [termTypes.disease],
        weight: -12.359763775778456,
        url: 'https://fr.wikipedia.org/wiki/Insuffisance_rénale',
    },
    Q281289: {
        id: 'Q281289',
        name: 'Photophobie',
        alias: [],
        types: [termTypes.sign],
        weight: -12.568109501931065,
        url: 'https://fr.wikipedia.org/wiki/Photophobie',
    },
    Q159557: {
        id: 'Q159557',
        name: 'Coma',
        alias: [
            'Perdre connaissance',
            'Coma végétatif',
            'Perte de connaissance',
        ],
        types: [termTypes.sign],
        weight: -11.415040299689283,
        url: 'https://wikimedi.ca/wiki/Coma',
    },
};

/**
 * Liste des relations de type « a pour symptôme » entre deux termes.
 */
export const hasSymptom = [
    ['Q2840', 'Q38933'],
    ['Q2840', 'Q1115038'],
    ['Q2840', 'Q474959'],
    ['Q2840', 'Q86'],
    ['Q2840', 'Q9690'],

    ['Q154882', 'Q86'],
    ['Q154882', 'Q38933'],
    ['Q154882', 'Q35805'],
    ['Q154882', 'Q474959'],

    ['Q155098', 'Q38933'],
    ['Q155098', 'Q474959'],
    ['Q155098', 'Q86'],
    ['Q155098', 'Q476921'],
    ['Q155098', 'Q186235'],
    ['Q155098', 'Q653197'],

    ['Q326663', 'Q86'],
    ['Q326663', 'Q474959'],
    ['Q326663', 'Q38933'],
    ['Q326663', 'Q9690'],
    ['Q326663', 'Q281289'],
    ['Q326663', 'Q159557'],
    ['Q326663', 'Q127076'],

    ['Q133780', 'Q38933'],
    ['Q133780', 'Q86'],
    ['Q133780', 'Q127076'],
    ['Q133780', 'Q474959'],
    ['Q133780', 'Q178061'],
    ['Q133780', 'Q35805'],
    ['Q133780', 'Q647099'],
    ['Q133780', 'Q653197'],
    ['Q133780', 'Q160796'],
];

/**
 * Liste des relations de type « est un symptôme de » entre deux termes.
 */
export const symptomOf = hasSymptom.map(([from, to]) => [to, from]);
